@@ -1,13 +1,13 @@
 use crate::ops::forc_fmt;
-use structopt::{self, StructOpt};
+use clap::Parser;
 
 /// Format all Sway files of the current project.
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 pub struct Command {
     /// Run in 'check' mode.
     /// Exits with 0 if input is formatted correctly.
     /// Exits with 1 and prints a diff if formatting is required.
-    #[structopt(short, long)]
+    #[clap(short, long)]
     pub check: bool,
 }
 
