@@ -1,12 +1,16 @@
-use structopt::StructOpt;
+use clap::Parser;
 
 mod commands;
 use self::commands::{
-    build, deploy, format, init, json_abi, lsp, parse_bytecode, run, test, update,
+    addr2line, build, clean, deploy, explorer, format, init, json_abi, lsp, parse_bytecode, run,
+    test, update,
 };
 
+use addr2line::Command as Addr2LineCommand;
 pub use build::Command as BuildCommand;
+pub use clean::Command as CleanCommand;
 pub use deploy::Command as DeployCommand;
+pub use explorer::Command as ExplorerCommand;
 pub use format::Command as FormatCommand;
 use init::Command as InitCommand;
 pub use json_abi::Command as JsonAbiCommand;
@@ -16,19 +20,23 @@ pub use run::Command as RunCommand;
 use test::Command as TestCommand;
 pub use update::Command as UpdateCommand;
 
-#[derive(Debug, StructOpt)]
-#[structopt(name = "forc", about = "Fuel Orchestrator")]
+#[derive(Debug, Parser)]
+#[clap(name = "forc", about = "Fuel Orchestrator")]
 struct Opt {
     /// the command to run
-    #[structopt(subcommand)]
+    #[clap(subcommand)]
     command: Forc,
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Parser)]
 enum Forc {
+    #[clap(name = "addr2line")]
+    Addr2Line(Addr2LineCommand),
     Build(BuildCommand),
+    Clean(CleanCommand),
     Deploy(DeployCommand),
-    #[structopt(name = "fmt")]
+    Explorer(ExplorerCommand),
+    #[clap(name = "fmt")]
     Format(FormatCommand),
     Init(InitCommand),
     ParseBytecode(ParseBytecodeCommand),
@@ -40,10 +48,13 @@ enum Forc {
 }
 
 pub(crate) async fn run_cli() -> Result<(), String> {
-    let opt = Opt::from_args();
+    let opt = Opt::parse();
     match opt.command {
+        Forc::Addr2Line(command) => addr2line::exec(command),
         Forc::Build(command) => build::exec(command),
+        Forc::Clean(command) => clean::exec(command),
         Forc::Deploy(command) => deploy::exec(command).await,
+        Forc::Explorer(command) => explorer::exec(command).await,
         Forc::Format(command) => format::exec(command),
         Forc::Init(command) => init::exec(command),
         Forc::ParseBytecode(command) => parse_bytecode::exec(command),
