@@ -4,33 +4,28 @@ use crate::{
     cli::BuildCommand,
     utils::dependency,
     utils::helpers::{
-        get_main_file, print_on_failure, print_on_success, print_on_success_library, read_manifest,
+        default_output_directory, get_main_file, print_on_failure, print_on_success,
+        print_on_success_library, read_manifest,
     },
 };
 use std::fs::{self, File};
 use std::io::Write;
 use std::sync::Arc;
 use sway_core::{FinalizedAsm, TreeType};
-use sway_utils::{constants, find_manifest_dir};
+use sway_utils::{find_manifest_dir, MANIFEST_FILE_NAME};
 
 use sway_core::{
     create_module, source_map::SourceMap, BuildConfig, BytecodeCompilationResult,
-    CompilationResult, NamespaceRef, NamespaceWrapper,
+    CompilationResult, CompileAstResult, NamespaceRef, NamespaceWrapper, TypedParseTree,
 };
+use sway_types::JsonABI;
 
 use anyhow::Result;
-use std::collections::{HashMap, HashSet};
 use std::path::{Path, PathBuf};
 
-pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
-    // find manifest directory, even if in subdirectory
-    let this_dir = if let Some(ref path) = command.path {
-        PathBuf::from(path)
-    } else {
-        std::env::current_dir().map_err(|e| format!("{:?}", e))?
-    };
-
+pub fn build(command: BuildCommand) -> Result<(Vec<u8>, JsonABI), String> {
     let BuildCommand {
+        path,
         binary_outfile,
         use_ir,
         debug_outfile,
@@ -39,32 +34,31 @@ pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
         print_ir,
         offline_mode,
         silent_mode,
-        ..
+        output_directory,
+        minify_json_abi,
     } = command;
+
+    // find manifest directory, even if in subdirectory
+    let this_dir = if let Some(ref path) = path {
+        PathBuf::from(path)
+    } else {
+        std::env::current_dir().map_err(|e| format!("{:?}", e))?
+    };
+
     let manifest_dir = match find_manifest_dir(&this_dir) {
         Some(dir) => dir,
         None => {
             return Err(format!(
-                "No manifest file found in this directory or any parent directories of it: {:?}",
-                this_dir
+                "could not find `{}` in `{}` or any parent directory",
+                MANIFEST_FILE_NAME,
+                this_dir.display(),
             ))
         }
     };
 
     let mut manifest = read_manifest(&manifest_dir)?;
-
-    let main_path = {
-        let mut code_dir = manifest_dir.clone();
-        code_dir.push(constants::SRC_DIR);
-        code_dir.push(&manifest.project.entry);
-        code_dir
-    };
-    let mut file_path = manifest_dir.clone();
-    file_path.pop();
-    let file_name = match main_path.strip_prefix(file_path.clone()) {
-        Ok(o) => o,
-        Err(err) => return Err(err.to_string()),
-    };
+    let main_path = find_main_path(&manifest_dir, &manifest);
+    let file_name = find_file_name(&manifest_dir, &main_path)?;
 
     let build_config = BuildConfig::root_from_file_name_and_manifest_path(
         file_name.to_path_buf(),
@@ -75,38 +69,49 @@ pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
     .print_intermediate_asm(print_intermediate_asm)
     .print_ir(print_ir);
 
-    let mut dependency_graph = HashMap::new();
     let namespace = create_module();
 
+    let mut source_map = SourceMap::new();
+    let mut json_abi = vec![];
+
     if let Some(ref mut deps) = manifest.dependencies {
         for (dependency_name, dependency_details) in deps.iter_mut() {
-            compile_dependency_lib(
+            let dep_json_abi = compile_dependency_lib(
                 &this_dir,
                 dependency_name,
                 dependency_details,
                 namespace,
-                &mut dependency_graph,
                 silent_mode,
                 offline_mode,
             )?;
+            json_abi.extend(dep_json_abi);
+
+            source_map.insert_dependency(match dependency_details {
+                Dependency::Simple(..) => {
+                    todo!("simple deps (compile_dependency_lib should have errored on this)");
+                }
+                Dependency::Detailed(DependencyDetails { path, .. }) => path
+                    .as_ref()
+                    .expect("compile_dependency_lib should have set this")
+                    .clone(),
+            });
         }
     }
 
     // now, compile this program with all of its dependencies
     let main_file = get_main_file(&manifest, &manifest_dir)?;
 
-    let mut source_map = SourceMap::new();
-
-    let main = compile(
+    let (main, main_json_abi) = compile(
         main_file,
         &manifest.project.name,
         namespace,
         build_config,
-        &mut dependency_graph,
         &mut source_map,
         silent_mode,
     )?;
 
+    json_abi.extend(main_json_abi);
+
     if let Some(outfile) = binary_outfile {
         let mut file = File::create(outfile).map_err(|e| e.to_string())?;
         file.write_all(main.as_slice()).map_err(|e| e.to_string())?;
@@ -115,27 +120,57 @@ pub fn build(command: BuildCommand) -> Result<Vec<u8>, String> {
     if let Some(outfile) = debug_outfile {
         fs::write(
             outfile,
-            &serde_json::to_vec(&source_map).expect("JSON seralizatio failed"),
+            &serde_json::to_vec(&source_map).expect("JSON serialization failed"),
         )
         .map_err(|e| e.to_string())?;
     }
 
+    // TODO: We may support custom build profiles in the future.
+    let profile = "debug";
+
+    // Create the output directory for build artifacts.
+    let output_dir = output_directory
+        .map(PathBuf::from)
+        .unwrap_or_else(|| default_output_directory(&manifest_dir).join(profile));
+    if !output_dir.exists() {
+        fs::create_dir_all(&output_dir).map_err(|e| e.to_string())?;
+    }
+
+    // Place build artifacts into the output directory.
+    let bin_path = output_dir
+        .join(&manifest.project.name)
+        .with_extension("bin");
+    std::fs::write(&bin_path, main.as_slice()).map_err(|e| e.to_string())?;
+    if !json_abi.is_empty() {
+        let json_abi_stem = format!("{}-abi", manifest.project.name);
+        let json_abi_path = output_dir.join(&json_abi_stem).with_extension("json");
+        let file = File::create(json_abi_path).map_err(|e| e.to_string())?;
+        let res = if minify_json_abi {
+            serde_json::to_writer(&file, &json_abi)
+        } else {
+            serde_json::to_writer_pretty(&file, &json_abi)
+        };
+        res.map_err(|e| e.to_string())?;
+    }
+
     println!("  Bytecode size is {} bytes.", main.len());
 
-    Ok(main)
+    Ok((main, json_abi))
 }
 
-/// Takes a dependency and returns a namespace of exported things from that dependency
-/// trait implementations are included as well
+/// Takes a dependency and returns a namespace of exported things from that dependency including
+/// trait implementations.
+///
+/// Also returns the JSON ABI of the library. This may be empty in the case that no `abi` was
+/// exposed.
 fn compile_dependency_lib<'manifest>(
     project_file_path: &Path,
     dependency_name: &'manifest str,
     dependency_lib: &mut Dependency,
     namespace: NamespaceRef,
-    dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
     offline_mode: bool,
-) -> Result<(), String> {
+) -> Result<JsonABI, String> {
     let mut details = match dependency_lib {
         Dependency::Simple(..) => {
             return Err(
@@ -221,7 +256,6 @@ fn compile_dependency_lib<'manifest>(
                 dependency_name,
                 dependency_lib,
                 dep_namespace,
-                dependency_graph,
                 silent_mode,
                 offline_mode,
             )?;
@@ -230,19 +264,17 @@ fn compile_dependency_lib<'manifest>(
 
     let main_file = get_main_file(&manifest_of_dep, &manifest_dir)?;
 
-    let compiled = compile_library(
+    let (compiled, json_abi) = compile_library(
         main_file,
         &manifest_of_dep.project.name,
         dep_namespace,
         build_config,
-        dependency_graph,
         silent_mode,
     )?;
 
     namespace.insert_module_ref(dependency_name.to_string(), compiled);
 
-    // nothing is returned from this method since it mutates the hashmaps it was given
-    Ok(())
+    Ok(json_abi)
 }
 
 fn compile_library(
@@ -250,29 +282,33 @@ fn compile_library(
     proj_name: &str,
     namespace: NamespaceRef,
     build_config: BuildConfig,
-    dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
-) -> Result<NamespaceRef, String> {
-    let res = sway_core::compile_to_asm(source, namespace, build_config, dependency_graph);
+) -> Result<(NamespaceRef, JsonABI), String> {
+    let res = sway_core::compile_to_ast(source, namespace, &build_config);
     match res {
-        CompilationResult::Library {
-            namespace,
+        CompileAstResult::Success {
+            parse_tree,
+            tree_type,
             warnings,
-            ..
         } => {
-            print_on_success_library(silent_mode, proj_name, warnings);
-            Ok(namespace)
+            let errors = vec![];
+            match tree_type {
+                TreeType::Library { .. } => {
+                    print_on_success_library(silent_mode, proj_name, &warnings);
+                    let json_abi = generate_json_abi(&*parse_tree);
+                    let namespace = parse_tree.get_namespace_ref();
+                    Ok((namespace, json_abi))
+                }
+                _ => {
+                    print_on_failure(silent_mode, &warnings, &errors);
+                    Err(format!("Failed to compile {}", proj_name))
+                }
+            }
         }
-        CompilationResult::Failure { errors, warnings } => {
-            print_on_failure(silent_mode, warnings, errors);
+        CompileAstResult::Failure { warnings, errors } => {
+            print_on_failure(silent_mode, &warnings, &errors);
             Err(format!("Failed to compile {}", proj_name))
         }
-        _ => {
-            return Err(format!(
-                "Project \"{}\" was included as a dependency but it is not a library.",
-                proj_name
-            ))
-        }
     }
 }
 
@@ -281,32 +317,45 @@ fn compile(
     proj_name: &str,
     namespace: NamespaceRef,
     build_config: BuildConfig,
-    dependency_graph: &mut HashMap<String, HashSet<String>>,
     source_map: &mut SourceMap,
     silent_mode: bool,
-) -> Result<Vec<u8>, String> {
-    let res = sway_core::compile_to_bytecode(
-        source,
-        namespace,
-        build_config,
-        dependency_graph,
-        source_map,
-    );
+) -> Result<(Vec<u8>, JsonABI), String> {
+    let ast_res = sway_core::compile_to_ast(source, namespace, &build_config);
+    let (json_abi, tree_type, warnings) = match &ast_res {
+        CompileAstResult::Success {
+            parse_tree,
+            tree_type,
+            warnings,
+        } => (generate_json_abi(&*parse_tree), tree_type, warnings),
+        CompileAstResult::Failure { warnings, errors } => {
+            print_on_failure(silent_mode, warnings, errors);
+            return Err(format!("Failed to compile {}", proj_name));
+        }
+    };
 
-    match res {
+    if let TreeType::Library { .. } = tree_type {
+        print_on_success(silent_mode, proj_name, warnings, tree_type.clone());
+        return Ok((vec![], json_abi));
+    }
+
+    let asm_res = sway_core::ast_to_asm(ast_res, &build_config);
+    let bc_res = sway_core::asm_to_bytecode(asm_res, source_map);
+
+    let bytes = match bc_res {
         BytecodeCompilationResult::Success { bytes, warnings } => {
-            print_on_success(silent_mode, proj_name, warnings, TreeType::Script {});
-            Ok(bytes)
+            print_on_success(silent_mode, proj_name, &warnings, TreeType::Script {});
+            bytes
         }
         BytecodeCompilationResult::Library { warnings } => {
-            print_on_success_library(silent_mode, proj_name, warnings);
-            Ok(vec![])
+            print_on_success_library(silent_mode, proj_name, &warnings);
+            vec![]
         }
         BytecodeCompilationResult::Failure { errors, warnings } => {
-            print_on_failure(silent_mode, warnings, errors);
-            Err(format!("Failed to compile {}", proj_name))
+            print_on_failure(silent_mode, &warnings, &errors);
+            return Err(format!("Failed to compile {}", proj_name));
         }
-    }
+    };
+    Ok((bytes, json_abi))
 }
 
 fn compile_to_asm(
@@ -314,22 +363,30 @@ fn compile_to_asm(
     proj_name: &str,
     namespace: NamespaceRef,
     build_config: BuildConfig,
-    dependency_graph: &mut HashMap<String, HashSet<String>>,
     silent_mode: bool,
 ) -> Result<FinalizedAsm, String> {
-    let res = sway_core::compile_to_asm(source, namespace, build_config, dependency_graph);
+    let res = sway_core::compile_to_asm(source, namespace, build_config);
     match res {
         CompilationResult::Success { asm, warnings } => {
-            print_on_success(silent_mode, proj_name, warnings, TreeType::Script {});
+            print_on_success(silent_mode, proj_name, &warnings, TreeType::Script {});
             Ok(asm)
         }
         CompilationResult::Library { warnings, .. } => {
-            print_on_success_library(silent_mode, proj_name, warnings);
+            print_on_success_library(silent_mode, proj_name, &warnings);
             Ok(FinalizedAsm::Library)
         }
         CompilationResult::Failure { errors, warnings } => {
-            print_on_failure(silent_mode, warnings, errors);
+            print_on_failure(silent_mode, &warnings, &errors);
             return Err(format!("Failed to compile {}", proj_name));
         }
     }
 }
+
+fn generate_json_abi(ast: &TypedParseTree) -> JsonABI {
+    match ast {
+        TypedParseTree::Contract { abi_entries, .. } => {
+            abi_entries.iter().map(|x| x.generate_json_abi()).collect()
+        }
+        _ => vec![],
+    }
+}
